// eslint-disable-next-line @typescript-eslint/no-unused-vars
import { AuthorizationHandler } from '@graphpolaris/shared/data-access/authorization';
import {
  assignNewGraphQueryResult,
  useAppDispatch,
} from '@graphpolaris/shared/data-access/store';
import { useEffect, useState } from 'react';
import GridLayout from 'react-grid-layout';
import Panel from '../web/components/panels/Panel';
import { RawJSONVis } from '../web/components/visualisations/RawJSONVis/rawjsonvis';
import LoginScreen from '../web/components/login/loginScreen';

export function App() {
  const dispatch = useAppDispatch();

  const [userAuthorized, setUserAuthorized] = useState<boolean>(false);

  // Attempt to Authorize the user
  const authorize = async () => {
    const authorized = await AuthorizationHandler.instance().Authorize();
    console.log('User authorized: ' + authorized);

    // If user is authorized don't show login screen
    if (authorized) {
      setUserAuthorized(true);
    }
  };

  useEffect(() => {
    authorize();
  }, []);

  return (
    <>
      {!userAuthorized && <LoginScreen />}
      <GridLayout
        className="layout"
        cols={10}
        rowHeight={30}
        width={window.innerWidth}
        style={{ zIndex: 0 }}
      >
        <div
          key="schema-panel"
          data-grid={{
            x: 0,
            y: 0,
            w: 3,
            h: 30,
            maxW: 5,
            isDraggable: false,
          }}
        >
          <Panel content="Schema Panel" color="white"></Panel>
        </div>
        <div
          key="query-panel"
          data-grid={{
            x: 3,
            y: 20,
            w: 5,
            h: 10,
            maxH: 20,
            isDraggable: false,
          }}
        >
          <Panel content="Query Panel" color="white"></Panel>
        </div>
        <div
          key="visualisation-panel"
          data-grid={{ x: 3, y: 0, w: 7, h: 20, isDraggable: false }}
        >
          <Panel content="Visualisation Panel" color="white">
            <div>
              <button
                onClick={() =>
                  dispatch(
                    assignNewGraphQueryResult({
                      nodes: [
                        {
                          id: 'agent/007',
                          attributes: { name: 'Daniel Craig' },
                        },
                      ],
                      links: [],
                    })
                  )
                }
              >
                Load in mock result
              </button>
              <button
                onClick={() =>
                  dispatch(assignNewGraphQueryResult({ nodes: [], links: [] }))
                }
              >
                Remove mock result
              </button>
            </div>
            <RawJSONVis />
            <div />
          </Panel>
        </div>
        <div
          key="history-panel"
          data-grid={{ x: 8, y: 20, w: 2, h: 10, isDraggable: false }}
        >
          <Panel content="History Channel" color="white"></Panel>
        </div>
      </GridLayout>
    </>
  );
}

export default App;
